@@ -88,7 +88,7 @@ class netcdf_basics(basics):
         Result is automaticaly wrote to object's attributes.
         """
         if isinstance(self.files, xr.Dataset):
-            return self.files
+            return self.files.copy()
         elif isinstance(self.files, str):
             return open_xrdataset(self.files)
         elif isinstance(self.files, list):
